@@ -12,12 +12,11 @@
 #  See the License for the specific language governing permissions and 
 #  limitations under the License. 
 """
-logtools.parers
-Parsers for some common log formats, e.g 
-Common Log Format (CLF) etc.
-These parsers can be used both programmaticaly
-as well as by the logtools command-line tools to
-meaningfully parse log fields from standard formats.
+logtools.parsers
+Parsers for some common log formats, e.g Common Log Format (CLF).
+These parsers can be used both programmaticaly as well as by the 
+logtools command-line tools to meaningfully parse log fields 
+from standard formats.
 """
 import os
 import re
@@ -28,8 +27,8 @@ from abc import ABCMeta, abstractmethod
 
 from _config import AttrDict
 
-__all__ = ['AccessLog', 'CommonLogFormat']
-
+__all__ = ['LogParser', 'AccessLogLine', 'AccessLog', 
+           'CommonLogFormat']
 
 class LogParser(object):
     """Base class for all our parsers"""
@@ -42,6 +41,11 @@ class LogParser(object):
     @abstractmethod
     def parse(self, line):
         """Parse a logline"""
+        
+    def set_format(self, format):
+        """Set a format specifier for parser.
+        Some parsers can use this to specify
+        a format string"""
 
 class AccessLogLine(dict):
     """Instrumented dictionary that allows
@@ -51,12 +55,16 @@ class AccessLogLine(dict):
     def __init__(self, fieldnames):
         self._fieldnames = dict(enumerate(fieldnames))
         
-    def by_index(self, i):
-        return self.by_key(self._fieldnames[i])
+    def by_index(self, i, raw=False):
+        return self.by_key(self._fieldnames[i], raw=raw)
     
-    def by_key(self, key):
+    def by_key(self, key, raw=False):
         """Return the i-th field parsed"""
         val = None
+        
+        if raw is True:
+            return self[key]
+        
         if key == '%t':
             val = datetime.strptime(self[key][1:-7], '%d/%b/%Y:%H:%M:%S')
         else:
@@ -69,14 +77,22 @@ class AccessLog(LogParser):
     consume arbitrary Apache log field directives. see
     http://httpd.apache.org/docs/1.3/logs.html#accesslog"""
 
-    def __init__(self, format):
+    def __init__(self, format=None):
         LogParser.__init__(self)
         
         self.fieldnames    = None
-        self.fieldselector = self._parse_log_format(format)
-        self._logline_wrapper = AccessLogLine(self.fieldnames)
+        self.fieldselector = None
+        self._logline_wrapper = None
         
+        if format:
+            self.fieldselector = self._parse_log_format(format)
+            self._logline_wrapper = AccessLogLine(self.fieldnames)     
 
+    def set_format(self, format):
+        """Set the access_log format"""
+        self.fieldselector = self._parse_log_format(format)
+        self._logline_wrapper = AccessLogLine(self.fieldnames)     
+        
     def parse(self, logline):
         """
         Parse log line into structured row.
@@ -104,7 +120,7 @@ class AccessLog(LogParser):
 
         findquotes = re.compile(r'^"')
         findreferreragent = re.compile('Referer|User-Agent')
-        findpercent = re.compile('^%.*t$')
+        findpercent = re.compile(r'^%.*t$')
         lstripquotes = re.compile(r'^"')
         rstripquotes = re.compile(r'"$')
         self.fieldnames = []
@@ -139,7 +155,6 @@ class AccessLog(LogParser):
         _pattern = '^' + ' '.join(subpatterns) + '$'
         _regex = re.compile(_pattern)
 
-        print _regex.pattern
         return _regex
 
     
