@@ -22,7 +22,8 @@ from StringIO import StringIO
 from operator import itemgetter
 
 from logtools import (filterbots, geoip, logsample, logsample_weighted, 
-                      logmerge, logplot)
+                      logparse, logmerge, logplot)
+from logtools.parsers import *
 from logtools import logtools_config, interpolate_config, AttrDict
 
 logging.basicConfig(level=logging.INFO)
@@ -33,6 +34,38 @@ class ConfigurationTestCase(unittest.TestCase):
         self.assertRaises(KeyError, interpolate_config, None, 'bogus_sec', 'bogus_key')
 
 
+class ParsingTestCase(unittest.TestCase):
+    def setUp(self):
+        self.clf_rows = [
+            '127.0.0.1 - frank [10/Oct/2000:13:55:36 -0700] "GET /apache_pb.gif HTTP/1.0" 200 2326',
+            '127.0.0.2 - jay [10/Oct/2000:13:56:12 -0700] "GET /apache_pb.gif HTTP/1.0" 200 2326'
+            ]
+        
+    def testAccessLog(self):
+        """Test Apache access_log format parser"""
+        parser = AccessLog()
+        parser.set_format(format='%h %l %u %t "%r" %>s %b')
+        self.assertRaises(ValueError, parser, 'example for invalid format')
+        for logrow in self.clf_rows:
+            parsed = parser(logrow)
+            self.assertNotEquals(parsed, None, "Could not parse line: %s" % str(logrow))
+            
+    def testCommonLogFormat(self):
+        """Test CLF Parser"""
+        parser = CommonLogFormat()
+        self.assertRaises(ValueError, parser, 'example for invalid format')
+        for logrow in self.clf_rows:
+            parsed = parser(logrow)
+            self.assertNotEquals(parsed, None, "Could not parse line: %s" % str(logrow))        
+        
+        
+    def testLogParse(self):
+        options = AttrDict({'parser': 'CommonLogFormat', 'field': 4})
+        fh = StringIO('\n'.join(self.clf_rows))
+        output = [l for l in logparse(options, None, fh)]
+        self.assertEquals(len(output), len(self.clf_rows), "Output size was not equal to input size!")
+        
+            
 class FilterBotsTestCase(unittest.TestCase):
     def setUp(self):
         self.options = AttrDict({
@@ -40,13 +73,15 @@ class FilterBotsTestCase(unittest.TestCase):
             "printlines": False,
             "ip_ua_re": "^(?P<ip>.*?) - USER_AGENT:'(?P<ua>.*?)'",
             "bots_ips": StringIO(),
-            "bots_ua": StringIO(
-                "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)\n"
-            )
+            "bots_ua": StringIO("\n".join([
+                "Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)",
+                "r'.*MSIECrawler'"
+                ]) + "\n")
         })
         self.fh = StringIO(
             "127.0.0.1 - USER_AGENT:'Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)' - ...\n" \
-            "255.255.255.255 - USER_AGENT:'Mozilla' - ...\n"
+            "255.255.255.255 - USER_AGENT:'Mozilla' - ...\n" \
+            "1.1.1.1 - USER_AGENT:'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; MSIECrawler)'\n"
         )
 
     def testFiltering(self):
@@ -73,7 +108,7 @@ class GeoIPTestCase(unittest.TestCase):
             return
 
         output = [(geocode, ip, line) for geocode, ip, line in geoip(self.options, None, self.fh)]
-        self.assertEquals(len(output), 2, "Output size was different than expected: %s", str(len(output)))
+        self.assertEquals(len(output), 2, "Output size was different than expected: %s" % str(len(output)))
 
         
 class SamplingTestCase(unittest.TestCase):
@@ -156,7 +191,6 @@ class PlotTestCase(unittest.TestCase):
             return        
         options = AttrDict({
             'backend': 'gchart',
-            'type': 'pie',
             'output': False,
             'limit': 10,
             'field': 1,
@@ -165,10 +199,18 @@ class PlotTestCase(unittest.TestCase):
             'width': 600,
             'height': 300
         })        
-        ret = logplot(options, None, self.fh)
+        chart = None
+        for plot_type in ('pie', 'line'):
+            self.fh.seek(0)
+            options['type'] = plot_type
+            chart = logplot(options, None, self.fh)
+            self.assertNotEquals(chart, None, "logplot returned None. Expected a Plot object")
+            
+        # Should raise ValueError here due to fh being at EOF
+        self.assertRaises(ValueError, logplot, options, None, self.fh)
+        
         tmp_fh, tmp_fname = mkstemp()
-        ret.download(tmp_fname)
-        self.assertNotEquals(ret, None, "logplot returned None. Expected a Plot object")
+        chart.download(tmp_fname)
         os.remove(tmp_fname)
     
 
